"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/parameters.lambda.ts
var parameters_lambda_exports = {};
__export(parameters_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(parameters_lambda_exports);
var crypto = __toESM(require("crypto"));
var import_client_rds = require("@aws-sdk/client-rds");
var rds = new import_client_rds.RDSClient();
function getDockerImage(engine) {
  if (engine.match(/(^aurora$|mysql|mariadb)/)) {
    return "mysql";
  } else if (engine.match(/postgres/)) {
    return "postgres";
  } else {
    throw new Error(`"${engine}" is not a supported database engine`);
  }
}
function confirmLength(name, value) {
  let error;
  if (value.length > 63) {
    error = "is too long";
  }
  if (!value.charAt(0).match(/[a-z]/i)) {
    error = "does not start with a letter";
  }
  if (value.indexOf("--") >= 0) {
    error = "contains two consecutive hyphens";
  }
  if (error) {
    throw new Error(`"${name}" ${error}. Try adjusting 'tempPrefix' and/or 'snapshotPrefix'. Current value: ${value}`);
  }
}
async function handler(input) {
  let port;
  let user;
  let engine;
  let kmsKeyId;
  let instanceClass;
  if (input.isCluster) {
    const origDb = await rds.send(new import_client_rds.DescribeDBClustersCommand({ DBClusterIdentifier: input.databaseIdentifier }));
    if (!origDb.DBClusters || origDb.DBClusters.length != 1) {
      throw new Error(`Unable to find ${input.databaseIdentifier}`);
    }
    const cluster = origDb.DBClusters[0];
    if (!cluster.Port || !cluster.MasterUsername || !cluster.DBClusterMembers) {
      throw new Error(`Database missing some required parameters: ${JSON.stringify(cluster)}`);
    }
    const origInstances = await rds.send(new import_client_rds.DescribeDBInstancesCommand({ DBInstanceIdentifier: cluster.DBClusterMembers[0].DBInstanceIdentifier }));
    if (!origInstances.DBInstances || origInstances.DBInstances.length < 1) {
      throw new Error(`Unable to find instances for ${input.databaseIdentifier}`);
    }
    const instance = origInstances.DBInstances[0];
    if (!instance.DBInstanceClass) {
      throw new Error(`Database instance missing class: ${JSON.stringify(instance)}`);
    }
    port = cluster.Port;
    user = cluster.MasterUsername;
    engine = cluster.Engine;
    kmsKeyId = cluster.KmsKeyId;
    instanceClass = instance.DBInstanceClass;
  } else {
    const origDb = await rds.send(new import_client_rds.DescribeDBInstancesCommand({ DBInstanceIdentifier: input.databaseIdentifier }));
    if (!origDb.DBInstances || origDb.DBInstances.length != 1) {
      throw new Error(`Unable to find ${input.databaseIdentifier}`);
    }
    const instance = origDb.DBInstances[0];
    if (!instance.Endpoint?.Address || !instance.Endpoint?.Port || !instance.MasterUsername) {
      throw new Error(`Database missing some required parameters: ${JSON.stringify(instance)}`);
    }
    port = instance.Endpoint.Port;
    user = instance.MasterUsername;
    engine = instance.Engine;
    kmsKeyId = instance.KmsKeyId;
    instanceClass = instance.DBInstanceClass ?? "db.m5.large";
  }
  if (input.databaseKey && input.databaseKey !== "") {
    if (input.databaseKey !== kmsKeyId) {
      throw new Error(`Database key (${kmsKeyId}) doesn't match databaseKey parameter (${input.databaseKey})`);
    }
  }
  const timestamp = /* @__PURE__ */ new Date();
  const snapshotSuffix = `-${timestamp.getUTCFullYear()}${(timestamp.getUTCMonth() + 1).toString().padStart(2, "0")}${timestamp.getUTCDate().toString().padStart(2, "0")}${timestamp.getUTCHours().toString().padStart(2, "0")}${timestamp.getUTCMinutes().toString().padStart(2, "0")}`;
  const targetSnapshotId = `${input.snapshotPrefix}${snapshotSuffix}`;
  const tempSuffix = crypto.randomBytes(8).toString("hex");
  const result = {
    databaseIdentifier: input.databaseIdentifier,
    isCluster: input.isCluster,
    engine: engine ?? "unknown",
    tempSnapshotId: `${input.tempPrefix}-${tempSuffix}`,
    tempEncSnapshotId: `${input.tempPrefix}-enc-${tempSuffix}`,
    tempDbId: `${input.tempPrefix}-${tempSuffix}`,
    tempDbInstanceId: `${input.tempPrefix}-inst-${tempSuffix}`,
    tempDbInstanceClass: instanceClass,
    targetSnapshotId,
    dockerImage: getDockerImage(engine ?? ""),
    tempDb: {
      host: {
        endpoint: "NOT KNOWN YET"
        // we want the temp db endpoint here
      },
      port: port.toString(),
      user,
      password: crypto.randomBytes(16).toString("hex")
    }
  };
  confirmLength("tempSnapshotId", result.tempSnapshotId);
  confirmLength("tempEncSnapshotId", result.tempEncSnapshotId);
  confirmLength("tempDbId", result.tempDbId);
  confirmLength("tempDbInstanceId", result.tempDbInstanceId);
  confirmLength("targetSnapshotId", result.targetSnapshotId);
  return result;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
